@@ -10,7 +10,7 @@ package Devel::Cover::DB;
 use strict;
 use warnings;
 
-our $VERSION = '1.09'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 use Devel::Cover::Criterion;
 use Devel::Cover::DB::File;
@@ -283,10 +283,11 @@ sub merge
 sub _merge_hash
 {
     my ($into, $from) = @_;
+    return unless $from;
     for my $fkey (keys %{$from})
     {
+        # print STDERR "key [$fkey]\n";
         my $fval = $from->{$fkey};
-        my $fval_ref = ref $fval;
 
         if (defined $into->{$fkey} and UNIVERSAL::isa($into->{$fkey}, "ARRAY"))
         {
@@ -1012,7 +1013,7 @@ Devel::Cover::DB - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 SYNOPSIS
 
